# 命令行

## 项目介绍

`FastAPI-Amis-Admin-Cli`是一个用于快速构建`FastAPI-Amis-Admin`项目的拓展库.

项目地址: [FastAPI-Amis-Admin-Cli](https://github.com/amisadmin/fastapi_amis_admin_cli),更多教程文档及使用示例正在持续补充,

## 安装

```bash
pip install fastapi-amis-admin-cli
```

## 快速使用

```bash
# 查看帮助
faa --help

# 初始化一个`FastAPI-Amis-Admin`项目
faa new project_name --init

# 初始化一个`FastAPI-Amis-Admin`应用
faa new app_name

# 快速运行项目
faa run
```

